# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .load_balancing_method import LoadBalancingMethod
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StickyCookieLoadBalancingMethod(LoadBalancingMethod):
    """
    An object that represents the `sticky-cookie` load balancing method and its properties.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new StickyCookieLoadBalancingMethod object with values from keyword arguments. The default value of the :py:attr:`~oci.waas.models.StickyCookieLoadBalancingMethod.method` attribute
        of this class is ``STICKY_COOKIE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param method:
            The value to assign to the method property of this StickyCookieLoadBalancingMethod.
            Allowed values for this property are: "IP_HASH", "ROUND_ROBIN", "STICKY_COOKIE"
        :type method: str

        :param name:
            The value to assign to the name property of this StickyCookieLoadBalancingMethod.
        :type name: str

        :param domain:
            The value to assign to the domain property of this StickyCookieLoadBalancingMethod.
        :type domain: str

        :param expiration_time_in_seconds:
            The value to assign to the expiration_time_in_seconds property of this StickyCookieLoadBalancingMethod.
        :type expiration_time_in_seconds: int

        """
        self.swagger_types = {
            'method': 'str',
            'name': 'str',
            'domain': 'str',
            'expiration_time_in_seconds': 'int'
        }

        self.attribute_map = {
            'method': 'method',
            'name': 'name',
            'domain': 'domain',
            'expiration_time_in_seconds': 'expirationTimeInSeconds'
        }

        self._method = None
        self._name = None
        self._domain = None
        self._expiration_time_in_seconds = None
        self._method = 'STICKY_COOKIE'

    @property
    def name(self):
        """
        Gets the name of this StickyCookieLoadBalancingMethod.
        The name of the cookie used to track the persistence.
        Can contain any US-ASCII character except separator or control character.


        :return: The name of this StickyCookieLoadBalancingMethod.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this StickyCookieLoadBalancingMethod.
        The name of the cookie used to track the persistence.
        Can contain any US-ASCII character except separator or control character.


        :param name: The name of this StickyCookieLoadBalancingMethod.
        :type: str
        """
        self._name = name

    @property
    def domain(self):
        """
        Gets the domain of this StickyCookieLoadBalancingMethod.
        The domain for which the cookie is set, defaults to WAAS policy domain.


        :return: The domain of this StickyCookieLoadBalancingMethod.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """
        Sets the domain of this StickyCookieLoadBalancingMethod.
        The domain for which the cookie is set, defaults to WAAS policy domain.


        :param domain: The domain of this StickyCookieLoadBalancingMethod.
        :type: str
        """
        self._domain = domain

    @property
    def expiration_time_in_seconds(self):
        """
        Gets the expiration_time_in_seconds of this StickyCookieLoadBalancingMethod.
        The time for which a browser should keep the cookie in seconds.
        Empty value will cause the cookie to expire at the end of a browser session.


        :return: The expiration_time_in_seconds of this StickyCookieLoadBalancingMethod.
        :rtype: int
        """
        return self._expiration_time_in_seconds

    @expiration_time_in_seconds.setter
    def expiration_time_in_seconds(self, expiration_time_in_seconds):
        """
        Sets the expiration_time_in_seconds of this StickyCookieLoadBalancingMethod.
        The time for which a browser should keep the cookie in seconds.
        Empty value will cause the cookie to expire at the end of a browser session.


        :param expiration_time_in_seconds: The expiration_time_in_seconds of this StickyCookieLoadBalancingMethod.
        :type: int
        """
        self._expiration_time_in_seconds = expiration_time_in_seconds

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Modified Work: Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Copyright 2008-2016 Andrey Petrov and contributors

from __future__ import absolute_import

# For backwards compatibility, provide imports that used to be here.
from .connection import is_connection_dropped
from .request import SKIP_HEADER, SKIPPABLE_HEADERS, make_headers
from .response import is_fp_closed
from .retry import Retry
from .ssl_ import (
    ALPN_PROTOCOLS,
    HAS_SNI,
    IS_PYOPENSSL,
    IS_SECURETRANSPORT,
    PROTOCOL_TLS,
    SSLContext,
    assert_fingerprint,
    resolve_cert_reqs,
    resolve_ssl_version,
    ssl_wrap_socket,
)
from .timeout import Timeout, current_time
from .url import Url, get_host, parse_url, split_first
from .wait import wait_for_read, wait_for_write

__all__ = (
    "HAS_SNI",
    "IS_PYOPENSSL",
    "IS_SECURETRANSPORT",
    "SSLContext",
    "PROTOCOL_TLS",
    "ALPN_PROTOCOLS",
    "Retry",
    "Timeout",
    "Url",
    "assert_fingerprint",
    "current_time",
    "is_connection_dropped",
    "is_fp_closed",
    "get_host",
    "parse_url",
    "make_headers",
    "resolve_cert_reqs",
    "resolve_ssl_version",
    "split_first",
    "ssl_wrap_socket",
    "wait_for_read",
    "wait_for_write",
    "SKIP_HEADER",
    "SKIPPABLE_HEADERS",
)



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ComputeInstanceGroupRolloutPolicy(object):
    """
    Specifies the rollout policy for compute instance group stages.
    """

    #: A constant which can be used with the policy_type property of a ComputeInstanceGroupRolloutPolicy.
    #: This constant has a value of "COMPUTE_INSTANCE_GROUP_LINEAR_ROLLOUT_POLICY_BY_COUNT"
    POLICY_TYPE_COMPUTE_INSTANCE_GROUP_LINEAR_ROLLOUT_POLICY_BY_COUNT = "COMPUTE_INSTANCE_GROUP_LINEAR_ROLLOUT_POLICY_BY_COUNT"

    #: A constant which can be used with the policy_type property of a ComputeInstanceGroupRolloutPolicy.
    #: This constant has a value of "COMPUTE_INSTANCE_GROUP_LINEAR_ROLLOUT_POLICY_BY_PERCENTAGE"
    POLICY_TYPE_COMPUTE_INSTANCE_GROUP_LINEAR_ROLLOUT_POLICY_BY_PERCENTAGE = "COMPUTE_INSTANCE_GROUP_LINEAR_ROLLOUT_POLICY_BY_PERCENTAGE"

    def __init__(self, **kwargs):
        """
        Initializes a new ComputeInstanceGroupRolloutPolicy object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.devops.models.ComputeInstanceGroupLinearRolloutPolicyByPercentage`
        * :class:`~oci.devops.models.ComputeInstanceGroupLinearRolloutPolicyByCount`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param policy_type:
            The value to assign to the policy_type property of this ComputeInstanceGroupRolloutPolicy.
            Allowed values for this property are: "COMPUTE_INSTANCE_GROUP_LINEAR_ROLLOUT_POLICY_BY_COUNT", "COMPUTE_INSTANCE_GROUP_LINEAR_ROLLOUT_POLICY_BY_PERCENTAGE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type policy_type: str

        :param batch_delay_in_seconds:
            The value to assign to the batch_delay_in_seconds property of this ComputeInstanceGroupRolloutPolicy.
        :type batch_delay_in_seconds: int

        """
        self.swagger_types = {
            'policy_type': 'str',
            'batch_delay_in_seconds': 'int'
        }

        self.attribute_map = {
            'policy_type': 'policyType',
            'batch_delay_in_seconds': 'batchDelayInSeconds'
        }

        self._policy_type = None
        self._batch_delay_in_seconds = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['policyType']

        if type == 'COMPUTE_INSTANCE_GROUP_LINEAR_ROLLOUT_POLICY_BY_PERCENTAGE':
            return 'ComputeInstanceGroupLinearRolloutPolicyByPercentage'

        if type == 'COMPUTE_INSTANCE_GROUP_LINEAR_ROLLOUT_POLICY_BY_COUNT':
            return 'ComputeInstanceGroupLinearRolloutPolicyByCount'
        else:
            return 'ComputeInstanceGroupRolloutPolicy'

    @property
    def policy_type(self):
        """
        **[Required]** Gets the policy_type of this ComputeInstanceGroupRolloutPolicy.
        The type of policy used for rolling out a deployment stage.

        Allowed values for this property are: "COMPUTE_INSTANCE_GROUP_LINEAR_ROLLOUT_POLICY_BY_COUNT", "COMPUTE_INSTANCE_GROUP_LINEAR_ROLLOUT_POLICY_BY_PERCENTAGE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The policy_type of this ComputeInstanceGroupRolloutPolicy.
        :rtype: str
        """
        return self._policy_type

    @policy_type.setter
    def policy_type(self, policy_type):
        """
        Sets the policy_type of this ComputeInstanceGroupRolloutPolicy.
        The type of policy used for rolling out a deployment stage.


        :param policy_type: The policy_type of this ComputeInstanceGroupRolloutPolicy.
        :type: str
        """
        allowed_values = ["COMPUTE_INSTANCE_GROUP_LINEAR_ROLLOUT_POLICY_BY_COUNT", "COMPUTE_INSTANCE_GROUP_LINEAR_ROLLOUT_POLICY_BY_PERCENTAGE"]
        if not value_allowed_none_or_none_sentinel(policy_type, allowed_values):
            policy_type = 'UNKNOWN_ENUM_VALUE'
        self._policy_type = policy_type

    @property
    def batch_delay_in_seconds(self):
        """
        Gets the batch_delay_in_seconds of this ComputeInstanceGroupRolloutPolicy.
        The duration of delay between batch rollout. The default delay is 1 minute.


        :return: The batch_delay_in_seconds of this ComputeInstanceGroupRolloutPolicy.
        :rtype: int
        """
        return self._batch_delay_in_seconds

    @batch_delay_in_seconds.setter
    def batch_delay_in_seconds(self, batch_delay_in_seconds):
        """
        Sets the batch_delay_in_seconds of this ComputeInstanceGroupRolloutPolicy.
        The duration of delay between batch rollout. The default delay is 1 minute.


        :param batch_delay_in_seconds: The batch_delay_in_seconds of this ComputeInstanceGroupRolloutPolicy.
        :type: int
        """
        self._batch_delay_in_seconds = batch_delay_in_seconds

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ValidatePatternResult(object):
    """
    Details regarding the validation of a pattern resource.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ValidatePatternResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param message:
            The value to assign to the message property of this ValidatePatternResult.
        :type message: str

        :param status:
            The value to assign to the status property of this ValidatePatternResult.
        :type status: str

        :param expression:
            The value to assign to the expression property of this ValidatePatternResult.
        :type expression: str

        :param derived_logical_entities:
            The value to assign to the derived_logical_entities property of this ValidatePatternResult.
        :type derived_logical_entities: list[oci.data_catalog.models.DerivedLogicalEntities]

        """
        self.swagger_types = {
            'message': 'str',
            'status': 'str',
            'expression': 'str',
            'derived_logical_entities': 'list[DerivedLogicalEntities]'
        }

        self.attribute_map = {
            'message': 'message',
            'status': 'status',
            'expression': 'expression',
            'derived_logical_entities': 'derivedLogicalEntities'
        }

        self._message = None
        self._status = None
        self._expression = None
        self._derived_logical_entities = None

    @property
    def message(self):
        """
        Gets the message of this ValidatePatternResult.
        The message from the pattern validation.


        :return: The message of this ValidatePatternResult.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this ValidatePatternResult.
        The message from the pattern validation.


        :param message: The message of this ValidatePatternResult.
        :type: str
        """
        self._message = message

    @property
    def status(self):
        """
        **[Required]** Gets the status of this ValidatePatternResult.
        The status returned from the pattern validation.


        :return: The status of this ValidatePatternResult.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this ValidatePatternResult.
        The status returned from the pattern validation.


        :param status: The status of this ValidatePatternResult.
        :type: str
        """
        self._status = status

    @property
    def expression(self):
        """
        Gets the expression of this ValidatePatternResult.
        The expression used in the pattern validation.


        :return: The expression of this ValidatePatternResult.
        :rtype: str
        """
        return self._expression

    @expression.setter
    def expression(self, expression):
        """
        Sets the expression of this ValidatePatternResult.
        The expression used in the pattern validation.


        :param expression: The expression of this ValidatePatternResult.
        :type: str
        """
        self._expression = expression

    @property
    def derived_logical_entities(self):
        """
        Gets the derived_logical_entities of this ValidatePatternResult.
        Collection of logical entities derived from the expression applied to a list of file paths.


        :return: The derived_logical_entities of this ValidatePatternResult.
        :rtype: list[oci.data_catalog.models.DerivedLogicalEntities]
        """
        return self._derived_logical_entities

    @derived_logical_entities.setter
    def derived_logical_entities(self, derived_logical_entities):
        """
        Sets the derived_logical_entities of this ValidatePatternResult.
        Collection of logical entities derived from the expression applied to a list of file paths.


        :param derived_logical_entities: The derived_logical_entities of this ValidatePatternResult.
        :type: list[oci.data_catalog.models.DerivedLogicalEntities]
        """
        self._derived_logical_entities = derived_logical_entities

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateClusterKubeconfigContentDetails(object):
    """
    The properties that define a request to create a cluster kubeconfig.
    """

    #: A constant which can be used with the endpoint property of a CreateClusterKubeconfigContentDetails.
    #: This constant has a value of "LEGACY_KUBERNETES"
    ENDPOINT_LEGACY_KUBERNETES = "LEGACY_KUBERNETES"

    #: A constant which can be used with the endpoint property of a CreateClusterKubeconfigContentDetails.
    #: This constant has a value of "PUBLIC_ENDPOINT"
    ENDPOINT_PUBLIC_ENDPOINT = "PUBLIC_ENDPOINT"

    #: A constant which can be used with the endpoint property of a CreateClusterKubeconfigContentDetails.
    #: This constant has a value of "PRIVATE_ENDPOINT"
    ENDPOINT_PRIVATE_ENDPOINT = "PRIVATE_ENDPOINT"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateClusterKubeconfigContentDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param token_version:
            The value to assign to the token_version property of this CreateClusterKubeconfigContentDetails.
        :type token_version: str

        :param expiration:
            The value to assign to the expiration property of this CreateClusterKubeconfigContentDetails.
        :type expiration: int

        :param endpoint:
            The value to assign to the endpoint property of this CreateClusterKubeconfigContentDetails.
            Allowed values for this property are: "LEGACY_KUBERNETES", "PUBLIC_ENDPOINT", "PRIVATE_ENDPOINT"
        :type endpoint: str

        """
        self.swagger_types = {
            'token_version': 'str',
            'expiration': 'int',
            'endpoint': 'str'
        }

        self.attribute_map = {
            'token_version': 'tokenVersion',
            'expiration': 'expiration',
            'endpoint': 'endpoint'
        }

        self._token_version = None
        self._expiration = None
        self._endpoint = None

    @property
    def token_version(self):
        """
        Gets the token_version of this CreateClusterKubeconfigContentDetails.
        The version of the kubeconfig token. Supported value 2.0.0


        :return: The token_version of this CreateClusterKubeconfigContentDetails.
        :rtype: str
        """
        return self._token_version

    @token_version.setter
    def token_version(self, token_version):
        """
        Sets the token_version of this CreateClusterKubeconfigContentDetails.
        The version of the kubeconfig token. Supported value 2.0.0


        :param token_version: The token_version of this CreateClusterKubeconfigContentDetails.
        :type: str
        """
        self._token_version = token_version

    @property
    def expiration(self):
        """
        Gets the expiration of this CreateClusterKubeconfigContentDetails.
        Deprecated. This field is no longer used.


        :return: The expiration of this CreateClusterKubeconfigContentDetails.
        :rtype: int
        """
        return self._expiration

    @expiration.setter
    def expiration(self, expiration):
        """
        Sets the expiration of this CreateClusterKubeconfigContentDetails.
        Deprecated. This field is no longer used.


        :param expiration: The expiration of this CreateClusterKubeconfigContentDetails.
        :type: int
        """
        self._expiration = expiration

    @property
    def endpoint(self):
        """
        Gets the endpoint of this CreateClusterKubeconfigContentDetails.
        The endpoint to target. A cluster may have multiple endpoints exposed but the kubeconfig can only target one at a time.

        Allowed values for this property are: "LEGACY_KUBERNETES", "PUBLIC_ENDPOINT", "PRIVATE_ENDPOINT"


        :return: The endpoint of this CreateClusterKubeconfigContentDetails.
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """
        Sets the endpoint of this CreateClusterKubeconfigContentDetails.
        The endpoint to target. A cluster may have multiple endpoints exposed but the kubeconfig can only target one at a time.


        :param endpoint: The endpoint of this CreateClusterKubeconfigContentDetails.
        :type: str
        """
        allowed_values = ["LEGACY_KUBERNETES", "PUBLIC_ENDPOINT", "PRIVATE_ENDPOINT"]
        if not value_allowed_none_or_none_sentinel(endpoint, allowed_values):
            raise ValueError(
                "Invalid value for `endpoint`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._endpoint = endpoint

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HeatWaveClusterSchemaMemoryEstimate(object):
    """
    Schema with estimated memory footprints for each MySQL user table
    of the schema when loaded to HeatWave cluster memory.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new HeatWaveClusterSchemaMemoryEstimate object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param schema_name:
            The value to assign to the schema_name property of this HeatWaveClusterSchemaMemoryEstimate.
        :type schema_name: str

        :param per_table_estimates:
            The value to assign to the per_table_estimates property of this HeatWaveClusterSchemaMemoryEstimate.
        :type per_table_estimates: list[oci.mysql.models.HeatWaveClusterTableMemoryEstimate]

        """
        self.swagger_types = {
            'schema_name': 'str',
            'per_table_estimates': 'list[HeatWaveClusterTableMemoryEstimate]'
        }

        self.attribute_map = {
            'schema_name': 'schemaName',
            'per_table_estimates': 'perTableEstimates'
        }

        self._schema_name = None
        self._per_table_estimates = None

    @property
    def schema_name(self):
        """
        **[Required]** Gets the schema_name of this HeatWaveClusterSchemaMemoryEstimate.
        The name of the schema.


        :return: The schema_name of this HeatWaveClusterSchemaMemoryEstimate.
        :rtype: str
        """
        return self._schema_name

    @schema_name.setter
    def schema_name(self, schema_name):
        """
        Sets the schema_name of this HeatWaveClusterSchemaMemoryEstimate.
        The name of the schema.


        :param schema_name: The schema_name of this HeatWaveClusterSchemaMemoryEstimate.
        :type: str
        """
        self._schema_name = schema_name

    @property
    def per_table_estimates(self):
        """
        **[Required]** Gets the per_table_estimates of this HeatWaveClusterSchemaMemoryEstimate.
        Estimated memory footprints for MySQL user tables of the schema
        when loaded to HeatWave cluster memory.


        :return: The per_table_estimates of this HeatWaveClusterSchemaMemoryEstimate.
        :rtype: list[oci.mysql.models.HeatWaveClusterTableMemoryEstimate]
        """
        return self._per_table_estimates

    @per_table_estimates.setter
    def per_table_estimates(self, per_table_estimates):
        """
        Sets the per_table_estimates of this HeatWaveClusterSchemaMemoryEstimate.
        Estimated memory footprints for MySQL user tables of the schema
        when loaded to HeatWave cluster memory.


        :param per_table_estimates: The per_table_estimates of this HeatWaveClusterSchemaMemoryEstimate.
        :type: list[oci.mysql.models.HeatWaveClusterTableMemoryEstimate]
        """
        self._per_table_estimates = per_table_estimates

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .base_type import BaseType
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class JavaType(BaseType):
    """
    A java type object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new JavaType object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.JavaType.model_type` attribute
        of this class is ``JAVA_TYPE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this JavaType.
            Allowed values for this property are: "DYNAMIC_TYPE", "STRUCTURED_TYPE", "DATA_TYPE", "JAVA_TYPE", "CONFIGURED_TYPE", "COMPOSITE_TYPE", "DERIVED_TYPE"
        :type model_type: str

        :param key:
            The value to assign to the key property of this JavaType.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this JavaType.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this JavaType.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this JavaType.
        :type name: str

        :param object_status:
            The value to assign to the object_status property of this JavaType.
        :type object_status: int

        :param description:
            The value to assign to the description property of this JavaType.
        :type description: str

        :param java_type_name:
            The value to assign to the java_type_name property of this JavaType.
        :type java_type_name: str

        :param config_definition:
            The value to assign to the config_definition property of this JavaType.
        :type config_definition: oci.data_integration.models.ConfigDefinition

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'object_status': 'int',
            'description': 'str',
            'java_type_name': 'str',
            'config_definition': 'ConfigDefinition'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'object_status': 'objectStatus',
            'description': 'description',
            'java_type_name': 'javaTypeName',
            'config_definition': 'configDefinition'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._object_status = None
        self._description = None
        self._java_type_name = None
        self._config_definition = None
        self._model_type = 'JAVA_TYPE'

    @property
    def java_type_name(self):
        """
        Gets the java_type_name of this JavaType.
        The java type name.


        :return: The java_type_name of this JavaType.
        :rtype: str
        """
        return self._java_type_name

    @java_type_name.setter
    def java_type_name(self, java_type_name):
        """
        Sets the java_type_name of this JavaType.
        The java type name.


        :param java_type_name: The java_type_name of this JavaType.
        :type: str
        """
        self._java_type_name = java_type_name

    @property
    def config_definition(self):
        """
        Gets the config_definition of this JavaType.

        :return: The config_definition of this JavaType.
        :rtype: oci.data_integration.models.ConfigDefinition
        """
        return self._config_definition

    @config_definition.setter
    def config_definition(self, config_definition):
        """
        Sets the config_definition of this JavaType.

        :param config_definition: The config_definition of this JavaType.
        :type: oci.data_integration.models.ConfigDefinition
        """
        self._config_definition = config_definition

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .apm_domain import ApmDomain
from .apm_domain_summary import ApmDomainSummary
from .base_domain_details import BaseDomainDetails
from .base_key_details import BaseKeyDetails
from .change_apm_domain_compartment_details import ChangeApmDomainCompartmentDetails
from .create_apm_domain_details import CreateApmDomainDetails
from .data_key import DataKey
from .data_key_summary import DataKeySummary
from .generate_data_key_details import GenerateDataKeyDetails
from .remove_data_key_details import RemoveDataKeyDetails
from .update_apm_domain_details import UpdateApmDomainDetails
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource

# Maps type names to classes for apm_control_plane services.
apm_control_plane_type_mapping = {
    "ApmDomain": ApmDomain,
    "ApmDomainSummary": ApmDomainSummary,
    "BaseDomainDetails": BaseDomainDetails,
    "BaseKeyDetails": BaseKeyDetails,
    "ChangeApmDomainCompartmentDetails": ChangeApmDomainCompartmentDetails,
    "CreateApmDomainDetails": CreateApmDomainDetails,
    "DataKey": DataKey,
    "DataKeySummary": DataKeySummary,
    "GenerateDataKeyDetails": GenerateDataKeyDetails,
    "RemoveDataKeyDetails": RemoveDataKeyDetails,
    "UpdateApmDomainDetails": UpdateApmDomainDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Alarm(object):
    """
    The properties that define an alarm.
    For information about alarms, see `Alarms Overview`__.

    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
    talk to an administrator. If you're an administrator who needs to write policies to give users access, see
    `Getting Started with Policies`__.

    For information about endpoints and signing API requests, see
    `About the API`__. For information about available SDKs and tools, see
    `SDKS and Other Tools`__.

    __ https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#AlarmsOverview
    __ https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm
    __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm
    __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/sdks.htm
    """

    #: A constant which can be used with the severity property of a Alarm.
    #: This constant has a value of "CRITICAL"
    SEVERITY_CRITICAL = "CRITICAL"

    #: A constant which can be used with the severity property of a Alarm.
    #: This constant has a value of "ERROR"
    SEVERITY_ERROR = "ERROR"

    #: A constant which can be used with the severity property of a Alarm.
    #: This constant has a value of "WARNING"
    SEVERITY_WARNING = "WARNING"

    #: A constant which can be used with the severity property of a Alarm.
    #: This constant has a value of "INFO"
    SEVERITY_INFO = "INFO"

    #: A constant which can be used with the message_format property of a Alarm.
    #: This constant has a value of "RAW"
    MESSAGE_FORMAT_RAW = "RAW"

    #: A constant which can be used with the message_format property of a Alarm.
    #: This constant has a value of "PRETTY_JSON"
    MESSAGE_FORMAT_PRETTY_JSON = "PRETTY_JSON"

    #: A constant which can be used with the message_format property of a Alarm.
    #: This constant has a value of "ONS_OPTIMIZED"
    MESSAGE_FORMAT_ONS_OPTIMIZED = "ONS_OPTIMIZED"

    #: A constant which can be used with the lifecycle_state property of a Alarm.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Alarm.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Alarm.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new Alarm object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Alarm.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this Alarm.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Alarm.
        :type compartment_id: str

        :param metric_compartment_id:
            The value to assign to the metric_compartment_id property of this Alarm.
        :type metric_compartment_id: str

        :param metric_compartment_id_in_subtree:
            The value to assign to the metric_compartment_id_in_subtree property of this Alarm.
        :type metric_compartment_id_in_subtree: bool

        :param namespace:
            The value to assign to the namespace property of this Alarm.
        :type namespace: str

        :param resource_group:
            The value to assign to the resource_group property of this Alarm.
        :type resource_group: str

        :param query:
            The value to assign to the query property of this Alarm.
        :type query: str

        :param resolution:
            The value to assign to the resolution property of this Alarm.
        :type resolution: str

        :param pending_duration:
            The value to assign to the pending_duration property of this Alarm.
        :type pending_duration: str

        :param severity:
            The value to assign to the severity property of this Alarm.
            Allowed values for this property are: "CRITICAL", "ERROR", "WARNING", "INFO", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type severity: str

        :param body:
            The value to assign to the body property of this Alarm.
        :type body: str

        :param message_format:
            The value to assign to the message_format property of this Alarm.
            Allowed values for this property are: "RAW", "PRETTY_JSON", "ONS_OPTIMIZED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type message_format: str

        :param destinations:
            The value to assign to the destinations property of this Alarm.
        :type destinations: list[str]

        :param repeat_notification_duration:
            The value to assign to the repeat_notification_duration property of this Alarm.
        :type repeat_notification_duration: str

        :param suppression:
            The value to assign to the suppression property of this Alarm.
        :type suppression: oci.monitoring.models.Suppression

        :param is_enabled:
            The value to assign to the is_enabled property of this Alarm.
        :type is_enabled: bool

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Alarm.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Alarm.
        :type defined_tags: dict(str, dict(str, object))

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Alarm.
            Allowed values for this property are: "ACTIVE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this Alarm.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Alarm.
        :type time_updated: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'metric_compartment_id': 'str',
            'metric_compartment_id_in_subtree': 'bool',
            'namespace': 'str',
            'resource_group': 'str',
            'query': 'str',
            'resolution': 'str',
            'pending_duration': 'str',
            'severity': 'str',
            'body': 'str',
            'message_format': 'str',
            'destinations': 'list[str]',
            'repeat_notification_duration': 'str',
            'suppression': 'Suppression',
            'is_enabled': 'bool',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'metric_compartment_id': 'metricCompartmentId',
            'metric_compartment_id_in_subtree': 'metricCompartmentIdInSubtree',
            'namespace': 'namespace',
            'resource_group': 'resourceGroup',
            'query': 'query',
            'resolution': 'resolution',
            'pending_duration': 'pendingDuration',
            'severity': 'severity',
            'body': 'body',
            'message_format': 'messageFormat',
            'destinations': 'destinations',
            'repeat_notification_duration': 'repeatNotificationDuration',
            'suppression': 'suppression',
            'is_enabled': 'isEnabled',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated'
        }

        self._id = None
        self._display_name = None
        self._compartment_id = None
        self._metric_compartment_id = None
        self._metric_compartment_id_in_subtree = None
        self._namespace = None
        self._resource_group = None
        self._query = None
        self._resolution = None
        self._pending_duration = None
        self._severity = None
        self._body = None
        self._message_format = None
        self._destinations = None
        self._repeat_notification_duration = None
        self._suppression = None
        self._is_enabled = None
        self._freeform_tags = None
        self._defined_tags = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Alarm.
        The `OCID`__ of the alarm.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this Alarm.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Alarm.
        The `OCID`__ of the alarm.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this Alarm.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this Alarm.
        A user-friendly name for the alarm. It does not have to be unique, and it's changeable.

        This name is sent as the title for notifications related to this alarm.

        Example: `High CPU Utilization`


        :return: The display_name of this Alarm.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Alarm.
        A user-friendly name for the alarm. It does not have to be unique, and it's changeable.

        This name is sent as the title for notifications related to this alarm.

        Example: `High CPU Utilization`


        :param display_name: The display_name of this Alarm.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Alarm.
        The `OCID`__ of the compartment containing the alarm.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this Alarm.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Alarm.
        The `OCID`__ of the compartment containing the alarm.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this Alarm.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def metric_compartment_id(self):
        """
        **[Required]** Gets the metric_compartment_id of this Alarm.
        The `OCID`__ of the compartment containing the metric
        being evaluated by the alarm.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The metric_compartment_id of this Alarm.
        :rtype: str
        """
        return self._metric_compartment_id

    @metric_compartment_id.setter
    def metric_compartment_id(self, metric_compartment_id):
        """
        Sets the metric_compartment_id of this Alarm.
        The `OCID`__ of the compartment containing the metric
        being evaluated by the alarm.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param metric_compartment_id: The metric_compartment_id of this Alarm.
        :type: str
        """
        self._metric_compartment_id = metric_compartment_id

    @property
    def metric_compartment_id_in_subtree(self):
        """
        Gets the metric_compartment_id_in_subtree of this Alarm.
        When true, the alarm evaluates metrics from all compartments and subcompartments. The parameter can
        only be set to true when metricCompartmentId is the tenancy OCID (the tenancy is the root compartment).
        A true value requires the user to have tenancy-level permissions. If this requirement is not met,
        then the call is rejected. When false, the alarm evaluates metrics from only the compartment specified
        in metricCompartmentId. Default is false.

        Example: `true`


        :return: The metric_compartment_id_in_subtree of this Alarm.
        :rtype: bool
        """
        return self._metric_compartment_id_in_subtree

    @metric_compartment_id_in_subtree.setter
    def metric_compartment_id_in_subtree(self, metric_compartment_id_in_subtree):
        """
        Sets the metric_compartment_id_in_subtree of this Alarm.
        When true, the alarm evaluates metrics from all compartments and subcompartments. The parameter can
        only be set to true when metricCompartmentId is the tenancy OCID (the tenancy is the root compartment).
        A true value requires the user to have tenancy-level permissions. If this requirement is not met,
        then the call is rejected. When false, the alarm evaluates metrics from only the compartment specified
        in metricCompartmentId. Default is false.

        Example: `true`


        :param metric_compartment_id_in_subtree: The metric_compartment_id_in_subtree of this Alarm.
        :type: bool
        """
        self._metric_compartment_id_in_subtree = metric_compartment_id_in_subtree

    @property
    def namespace(self):
        """
        **[Required]** Gets the namespace of this Alarm.
        The source service or application emitting the metric that is evaluated by the alarm.

        Example: `oci_computeagent`


        :return: The namespace of this Alarm.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """
        Sets the namespace of this Alarm.
        The source service or application emitting the metric that is evaluated by the alarm.

        Example: `oci_computeagent`


        :param namespace: The namespace of this Alarm.
        :type: str
        """
        self._namespace = namespace

    @property
    def resource_group(self):
        """
        Gets the resource_group of this Alarm.
        Resource group to match for metric data retrieved by the alarm. A resource group is a custom string that you can match when retrieving custom metrics. Only one resource group can be applied per metric.
        A valid resourceGroup value starts with an alphabetical character and includes only alphanumeric characters, periods (.), underscores (_), hyphens (-), and dollar signs ($).

        Example: `frontend-fleet`


        :return: The resource_group of this Alarm.
        :rtype: str
        """
        return self._resource_group

    @resource_group.setter
    def resource_group(self, resource_group):
        """
        Sets the resource_group of this Alarm.
        Resource group to match for metric data retrieved by the alarm. A resource group is a custom string that you can match when retrieving custom metrics. Only one resource group can be applied per metric.
        A valid resourceGroup value starts with an alphabetical character and includes only alphanumeric characters, periods (.), underscores (_), hyphens (-), and dollar signs ($).

        Example: `frontend-fleet`


        :param resource_group: The resource_group of this Alarm.
        :type: str
        """
        self._resource_group = resource_group

    @property
    def query(self):
        """
        **[Required]** Gets the query of this Alarm.
        The Monitoring Query Language (MQL) expression to evaluate for the alarm. The Alarms feature of
        the Monitoring service interprets results for each returned time series as Boolean values,
        where zero represents false and a non-zero value represents true. A true value means that the trigger
        rule condition has been met. The query must specify a metric, statistic, interval, and trigger
        rule (threshold or absence). Supported values for interval depend on the specified time range. More
        interval values are supported for smaller time ranges. You can optionally
        specify dimensions and grouping functions. Supported grouping functions: `grouping()`, `groupBy()`.
        For details about Monitoring Query Language (MQL), see `Monitoring Query Language (MQL) Reference`__.
        For available dimensions, review the metric definition for the supported service.
        See `Supported Services`__.

        Example of threshold alarm:

          -----

            CpuUtilization[1m]{availabilityDomain=\"cumS:PHX-AD-1\"}.groupBy(availabilityDomain).percentile(0.9) > 85

          -----

        Example of absence alarm:

          -----

            CpuUtilization[1m]{availabilityDomain=\"cumS:PHX-AD-1\"}.absent()

          -----

        __ https://docs.cloud.oracle.com/iaas/Content/Monitoring/Reference/mql.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#SupportedServices


        :return: The query of this Alarm.
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """
        Sets the query of this Alarm.
        The Monitoring Query Language (MQL) expression to evaluate for the alarm. The Alarms feature of
        the Monitoring service interprets results for each returned time series as Boolean values,
        where zero represents false and a non-zero value represents true. A true value means that the trigger
        rule condition has been met. The query must specify a metric, statistic, interval, and trigger
        rule (threshold or absence). Supported values for interval depend on the specified time range. More
        interval values are supported for smaller time ranges. You can optionally
        specify dimensions and grouping functions. Supported grouping functions: `grouping()`, `groupBy()`.
        For details about Monitoring Query Language (MQL), see `Monitoring Query Language (MQL) Reference`__.
        For available dimensions, review the metric definition for the supported service.
        See `Supported Services`__.

        Example of threshold alarm:

          -----

            CpuUtilization[1m]{availabilityDomain=\"cumS:PHX-AD-1\"}.groupBy(availabilityDomain).percentile(0.9) > 85

          -----

        Example of absence alarm:

          -----

            CpuUtilization[1m]{availabilityDomain=\"cumS:PHX-AD-1\"}.absent()

          -----

        __ https://docs.cloud.oracle.com/iaas/Content/Monitoring/Reference/mql.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#SupportedServices


        :param query: The query of this Alarm.
        :type: str
        """
        self._query = query

    @property
    def resolution(self):
        """
        Gets the resolution of this Alarm.
        The time between calculated aggregation windows for the alarm. Supported value: `1m`


        :return: The resolution of this Alarm.
        :rtype: str
        """
        return self._resolution

    @resolution.setter
    def resolution(self, resolution):
        """
        Sets the resolution of this Alarm.
        The time between calculated aggregation windows for the alarm. Supported value: `1m`


        :param resolution: The resolution of this Alarm.
        :type: str
        """
        self._resolution = resolution

    @property
    def pending_duration(self):
        """
        Gets the pending_duration of this Alarm.
        The period of time that the condition defined in the alarm must persist before the alarm state
        changes from \"OK\" to \"FIRING\". For example, a value of 5 minutes means that the
        alarm must persist in breaching the condition for five minutes before the alarm updates its
        state to \"FIRING\".

        The duration is specified as a string in ISO 8601 format (`PT10M` for ten minutes or `PT1H`
        for one hour). Minimum: PT1M. Maximum: PT1H. Default: PT1M.

        Under the default value of PT1M, the first evaluation that breaches the alarm updates the
        state to \"FIRING\".

        The alarm updates its status to \"OK\" when the breaching condition has been clear for
        the most recent minute.

        Example: `PT5M`


        :return: The pending_duration of this Alarm.
        :rtype: str
        """
        return self._pending_duration

    @pending_duration.setter
    def pending_duration(self, pending_duration):
        """
        Sets the pending_duration of this Alarm.
        The period of time that the condition defined in the alarm must persist before the alarm state
        changes from \"OK\" to \"FIRING\". For example, a value of 5 minutes means that the
        alarm must persist in breaching the condition for five minutes before the alarm updates its
        state to \"FIRING\".

        The duration is specified as a string in ISO 8601 format (`PT10M` for ten minutes or `PT1H`
        for one hour). Minimum: PT1M. Maximum: PT1H. Default: PT1M.

        Under the default value of PT1M, the first evaluation that breaches the alarm updates the
        state to \"FIRING\".

        The alarm updates its status to \"OK\" when the breaching condition has been clear for
        the most recent minute.

        Example: `PT5M`


        :param pending_duration: The pending_duration of this Alarm.
        :type: str
        """
        self._pending_duration = pending_duration

    @property
    def severity(self):
        """
        **[Required]** Gets the severity of this Alarm.
        The perceived type of response required when the alarm is in the \"FIRING\" state.

        Example: `CRITICAL`

        Allowed values for this property are: "CRITICAL", "ERROR", "WARNING", "INFO", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The severity of this Alarm.
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """
        Sets the severity of this Alarm.
        The perceived type of response required when the alarm is in the \"FIRING\" state.

        Example: `CRITICAL`


        :param severity: The severity of this Alarm.
        :type: str
        """
        allowed_values = ["CRITICAL", "ERROR", "WARNING", "INFO"]
        if not value_allowed_none_or_none_sentinel(severity, allowed_values):
            severity = 'UNKNOWN_ENUM_VALUE'
        self._severity = severity

    @property
    def body(self):
        """
        Gets the body of this Alarm.
        The human-readable content of the notification delivered. Oracle recommends providing guidance
        to operators for resolving the alarm condition. Consider adding links to standard runbook
        practices.

        Example: `High CPU usage alert. Follow runbook instructions for resolution.`


        :return: The body of this Alarm.
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """
        Sets the body of this Alarm.
        The human-readable content of the notification delivered. Oracle recommends providing guidance
        to operators for resolving the alarm condition. Consider adding links to standard runbook
        practices.

        Example: `High CPU usage alert. Follow runbook instructions for resolution.`


        :param body: The body of this Alarm.
        :type: str
        """
        self._body = body

    @property
    def message_format(self):
        """
        Gets the message_format of this Alarm.
        The format to use for notification messages sent from this alarm. The formats are:
        * `RAW` - Raw JSON blob. Default value.
        * `PRETTY_JSON`: JSON with new lines and indents.
        * `ONS_OPTIMIZED`: Simplified, user-friendly layout. Applies only to messages sent through the Notifications service to the following subscription types: Email.

        Allowed values for this property are: "RAW", "PRETTY_JSON", "ONS_OPTIMIZED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The message_format of this Alarm.
        :rtype: str
        """
        return self._message_format

    @message_format.setter
    def message_format(self, message_format):
        """
        Sets the message_format of this Alarm.
        The format to use for notification messages sent from this alarm. The formats are:
        * `RAW` - Raw JSON blob. Default value.
        * `PRETTY_JSON`: JSON with new lines and indents.
        * `ONS_OPTIMIZED`: Simplified, user-friendly layout. Applies only to messages sent through the Notifications service to the following subscription types: Email.


        :param message_format: The message_format of this Alarm.
        :type: str
        """
        allowed_values = ["RAW", "PRETTY_JSON", "ONS_OPTIMIZED"]
        if not value_allowed_none_or_none_sentinel(message_format, allowed_values):
            message_format = 'UNKNOWN_ENUM_VALUE'
        self._message_format = message_format

    @property
    def destinations(self):
        """
        **[Required]** Gets the destinations of this Alarm.
        A list of destinations to which the notifications for this alarm will be delivered.
        Each destination is represented by an `OCID`__ related to the supported destination service.
        For example, a destination using the Notifications service is represented by a topic OCID.
        Supported destination services: Notifications Service. Limit: One destination per supported destination service.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The destinations of this Alarm.
        :rtype: list[str]
        """
        return self._destinations

    @destinations.setter
    def destinations(self, destinations):
        """
        Sets the destinations of this Alarm.
        A list of destinations to which the notifications for this alarm will be delivered.
        Each destination is represented by an `OCID`__ related to the supported destination service.
        For example, a destination using the Notifications service is represented by a topic OCID.
        Supported destination services: Notifications Service. Limit: One destination per supported destination service.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param destinations: The destinations of this Alarm.
        :type: list[str]
        """
        self._destinations = destinations

    @property
    def repeat_notification_duration(self):
        """
        Gets the repeat_notification_duration of this Alarm.
        The frequency at which notifications are re-submitted, if the alarm keeps firing without
        interruption. Format defined by ISO 8601. For example, `PT4H` indicates four hours.
        Minimum: PT1M. Maximum: P30D.

        Default value: null (notifications are not re-submitted).

        Example: `PT2H`


        :return: The repeat_notification_duration of this Alarm.
        :rtype: str
        """
        return self._repeat_notification_duration

    @repeat_notification_duration.setter
    def repeat_notification_duration(self, repeat_notification_duration):
        """
        Sets the repeat_notification_duration of this Alarm.
        The frequency at which notifications are re-submitted, if the alarm keeps firing without
        interruption. Format defined by ISO 8601. For example, `PT4H` indicates four hours.
        Minimum: PT1M. Maximum: P30D.

        Default value: null (notifications are not re-submitted).

        Example: `PT2H`


        :param repeat_notification_duration: The repeat_notification_duration of this Alarm.
        :type: str
        """
        self._repeat_notification_duration = repeat_notification_duration

    @property
    def suppression(self):
        """
        Gets the suppression of this Alarm.
        The configuration details for suppressing an alarm.


        :return: The suppression of this Alarm.
        :rtype: oci.monitoring.models.Suppression
        """
        return self._suppression

    @suppression.setter
    def suppression(self, suppression):
        """
        Sets the suppression of this Alarm.
        The configuration details for suppressing an alarm.


        :param suppression: The suppression of this Alarm.
        :type: oci.monitoring.models.Suppression
        """
        self._suppression = suppression

    @property
    def is_enabled(self):
        """
        **[Required]** Gets the is_enabled of this Alarm.
        Whether the alarm is enabled.

        Example: `true`


        :return: The is_enabled of this Alarm.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this Alarm.
        Whether the alarm is enabled.

        Example: `true`


        :param is_enabled: The is_enabled of this Alarm.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Alarm.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"Department\": \"Finance\"}`


        :return: The freeform_tags of this Alarm.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Alarm.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"Department\": \"Finance\"}`


        :param freeform_tags: The freeform_tags of this Alarm.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Alarm.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`


        :return: The defined_tags of this Alarm.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Alarm.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`


        :param defined_tags: The defined_tags of this Alarm.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this Alarm.
        The current lifecycle state of the alarm.

        Example: `DELETED`

        Allowed values for this property are: "ACTIVE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Alarm.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Alarm.
        The current lifecycle state of the alarm.

        Example: `DELETED`


        :param lifecycle_state: The lifecycle_state of this Alarm.
        :type: str
        """
        allowed_values = ["ACTIVE", "DELETING", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this Alarm.
        The date and time the alarm was created. Format defined by RFC3339.

        Example: `2019-02-01T01:02:29.600Z`


        :return: The time_created of this Alarm.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Alarm.
        The date and time the alarm was created. Format defined by RFC3339.

        Example: `2019-02-01T01:02:29.600Z`


        :param time_created: The time_created of this Alarm.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this Alarm.
        The date and time the alarm was last updated. Format defined by RFC3339.

        Example: `2019-02-03T01:02:29.600Z`


        :return: The time_updated of this Alarm.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Alarm.
        The date and time the alarm was last updated. Format defined by RFC3339.

        Example: `2019-02-03T01:02:29.600Z`


        :param time_updated: The time_updated of this Alarm.
        :type: datetime
        """
        self._time_updated = time_updated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ChangeDatabaseParametersDetails(object):
    """
    The details required to change database parameter values.
    """

    #: A constant which can be used with the scope property of a ChangeDatabaseParametersDetails.
    #: This constant has a value of "MEMORY"
    SCOPE_MEMORY = "MEMORY"

    #: A constant which can be used with the scope property of a ChangeDatabaseParametersDetails.
    #: This constant has a value of "SPFILE"
    SCOPE_SPFILE = "SPFILE"

    #: A constant which can be used with the scope property of a ChangeDatabaseParametersDetails.
    #: This constant has a value of "BOTH"
    SCOPE_BOTH = "BOTH"

    def __init__(self, **kwargs):
        """
        Initializes a new ChangeDatabaseParametersDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param credentials:
            The value to assign to the credentials property of this ChangeDatabaseParametersDetails.
        :type credentials: oci.database_management.models.DatabaseCredentials

        :param scope:
            The value to assign to the scope property of this ChangeDatabaseParametersDetails.
            Allowed values for this property are: "MEMORY", "SPFILE", "BOTH"
        :type scope: str

        :param parameters:
            The value to assign to the parameters property of this ChangeDatabaseParametersDetails.
        :type parameters: list[oci.database_management.models.ChangeDatabaseParameterDetails]

        """
        self.swagger_types = {
            'credentials': 'DatabaseCredentials',
            'scope': 'str',
            'parameters': 'list[ChangeDatabaseParameterDetails]'
        }

        self.attribute_map = {
            'credentials': 'credentials',
            'scope': 'scope',
            'parameters': 'parameters'
        }

        self._credentials = None
        self._scope = None
        self._parameters = None

    @property
    def credentials(self):
        """
        **[Required]** Gets the credentials of this ChangeDatabaseParametersDetails.

        :return: The credentials of this ChangeDatabaseParametersDetails.
        :rtype: oci.database_management.models.DatabaseCredentials
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials):
        """
        Sets the credentials of this ChangeDatabaseParametersDetails.

        :param credentials: The credentials of this ChangeDatabaseParametersDetails.
        :type: oci.database_management.models.DatabaseCredentials
        """
        self._credentials = credentials

    @property
    def scope(self):
        """
        **[Required]** Gets the scope of this ChangeDatabaseParametersDetails.
        The clause used to specify when the parameter change takes effect.

        Use `MEMORY` to make the change in memory and affect it immediately.
        Use `SPFILE` to make the change in the server parameter file. The
        change takes effect when the database is next shut down and started
        up again. Use `BOTH` to make the change in memory and in the server
        parameter file. The change takes effect immediately and persists
        after the database is shut down and started up again.

        Allowed values for this property are: "MEMORY", "SPFILE", "BOTH"


        :return: The scope of this ChangeDatabaseParametersDetails.
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """
        Sets the scope of this ChangeDatabaseParametersDetails.
        The clause used to specify when the parameter change takes effect.

        Use `MEMORY` to make the change in memory and affect it immediately.
        Use `SPFILE` to make the change in the server parameter file. The
        change takes effect when the database is next shut down and started
        up again. Use `BOTH` to make the change in memory and in the server
        parameter file. The change takes effect immediately and persists
        after the database is shut down and started up again.


        :param scope: The scope of this ChangeDatabaseParametersDetails.
        :type: str
        """
        allowed_values = ["MEMORY", "SPFILE", "BOTH"]
        if not value_allowed_none_or_none_sentinel(scope, allowed_values):
            raise ValueError(
                "Invalid value for `scope`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._scope = scope

    @property
    def parameters(self):
        """
        **[Required]** Gets the parameters of this ChangeDatabaseParametersDetails.
        A list of database parameters and their values.


        :return: The parameters of this ChangeDatabaseParametersDetails.
        :rtype: list[oci.database_management.models.ChangeDatabaseParameterDetails]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this ChangeDatabaseParametersDetails.
        A list of database parameters and their values.


        :param parameters: The parameters of this ChangeDatabaseParametersDetails.
        :type: list[oci.database_management.models.ChangeDatabaseParameterDetails]
        """
        self._parameters = parameters

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SecurityAssessment(object):
    """
    A security assessment that provides an overall insight into your database security posture.
    The security assessment results are based on the analysis of your database configurations,
    user accounts, and security controls. For more information, see `Security Assessment Overview`__.

    __ https://docs.oracle.com/en/cloud/paas/data-safe/udscs/security-assessment-overview.html
    """

    #: A constant which can be used with the lifecycle_state property of a SecurityAssessment.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a SecurityAssessment.
    #: This constant has a value of "SUCCEEDED"
    LIFECYCLE_STATE_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the lifecycle_state property of a SecurityAssessment.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a SecurityAssessment.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a SecurityAssessment.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the triggered_by property of a SecurityAssessment.
    #: This constant has a value of "USER"
    TRIGGERED_BY_USER = "USER"

    #: A constant which can be used with the triggered_by property of a SecurityAssessment.
    #: This constant has a value of "SYSTEM"
    TRIGGERED_BY_SYSTEM = "SYSTEM"

    #: A constant which can be used with the type property of a SecurityAssessment.
    #: This constant has a value of "LATEST"
    TYPE_LATEST = "LATEST"

    #: A constant which can be used with the type property of a SecurityAssessment.
    #: This constant has a value of "SAVED"
    TYPE_SAVED = "SAVED"

    #: A constant which can be used with the type property of a SecurityAssessment.
    #: This constant has a value of "SAVE_SCHEDULE"
    TYPE_SAVE_SCHEDULE = "SAVE_SCHEDULE"

    #: A constant which can be used with the type property of a SecurityAssessment.
    #: This constant has a value of "COMPARTMENT"
    TYPE_COMPARTMENT = "COMPARTMENT"

    def __init__(self, **kwargs):
        """
        Initializes a new SecurityAssessment object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this SecurityAssessment.
        :type id: str

        :param time_created:
            The value to assign to the time_created property of this SecurityAssessment.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this SecurityAssessment.
        :type time_updated: datetime

        :param compartment_id:
            The value to assign to the compartment_id property of this SecurityAssessment.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this SecurityAssessment.
        :type display_name: str

        :param target_ids:
            The value to assign to the target_ids property of this SecurityAssessment.
        :type target_ids: list[str]

        :param ignored_targets:
            The value to assign to the ignored_targets property of this SecurityAssessment.
        :type ignored_targets: list[object]

        :param ignored_assessment_ids:
            The value to assign to the ignored_assessment_ids property of this SecurityAssessment.
        :type ignored_assessment_ids: list[object]

        :param target_version:
            The value to assign to the target_version property of this SecurityAssessment.
        :type target_version: str

        :param is_baseline:
            The value to assign to the is_baseline property of this SecurityAssessment.
        :type is_baseline: bool

        :param is_deviated_from_baseline:
            The value to assign to the is_deviated_from_baseline property of this SecurityAssessment.
        :type is_deviated_from_baseline: bool

        :param last_compared_baseline_id:
            The value to assign to the last_compared_baseline_id property of this SecurityAssessment.
        :type last_compared_baseline_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this SecurityAssessment.
            Allowed values for this property are: "CREATING", "SUCCEEDED", "UPDATING", "DELETING", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this SecurityAssessment.
        :type lifecycle_details: str

        :param schedule_security_assessment_id:
            The value to assign to the schedule_security_assessment_id property of this SecurityAssessment.
        :type schedule_security_assessment_id: str

        :param triggered_by:
            The value to assign to the triggered_by property of this SecurityAssessment.
            Allowed values for this property are: "USER", "SYSTEM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type triggered_by: str

        :param description:
            The value to assign to the description property of this SecurityAssessment.
        :type description: str

        :param schedule:
            The value to assign to the schedule property of this SecurityAssessment.
        :type schedule: str

        :param link:
            The value to assign to the link property of this SecurityAssessment.
        :type link: str

        :param type:
            The value to assign to the type property of this SecurityAssessment.
            Allowed values for this property are: "LATEST", "SAVED", "SAVE_SCHEDULE", "COMPARTMENT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param statistics:
            The value to assign to the statistics property of this SecurityAssessment.
        :type statistics: oci.data_safe.models.SecurityAssessmentStatistics

        :param freeform_tags:
            The value to assign to the freeform_tags property of this SecurityAssessment.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this SecurityAssessment.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this SecurityAssessment.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'compartment_id': 'str',
            'display_name': 'str',
            'target_ids': 'list[str]',
            'ignored_targets': 'list[object]',
            'ignored_assessment_ids': 'list[object]',
            'target_version': 'str',
            'is_baseline': 'bool',
            'is_deviated_from_baseline': 'bool',
            'last_compared_baseline_id': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'schedule_security_assessment_id': 'str',
            'triggered_by': 'str',
            'description': 'str',
            'schedule': 'str',
            'link': 'str',
            'type': 'str',
            'statistics': 'SecurityAssessmentStatistics',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'target_ids': 'targetIds',
            'ignored_targets': 'ignoredTargets',
            'ignored_assessment_ids': 'ignoredAssessmentIds',
            'target_version': 'targetVersion',
            'is_baseline': 'isBaseline',
            'is_deviated_from_baseline': 'isDeviatedFromBaseline',
            'last_compared_baseline_id': 'lastComparedBaselineId',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'schedule_security_assessment_id': 'scheduleSecurityAssessmentId',
            'triggered_by': 'triggeredBy',
            'description': 'description',
            'schedule': 'schedule',
            'link': 'link',
            'type': 'type',
            'statistics': 'statistics',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._time_created = None
        self._time_updated = None
        self._compartment_id = None
        self._display_name = None
        self._target_ids = None
        self._ignored_targets = None
        self._ignored_assessment_ids = None
        self._target_version = None
        self._is_baseline = None
        self._is_deviated_from_baseline = None
        self._last_compared_baseline_id = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._schedule_security_assessment_id = None
        self._triggered_by = None
        self._description = None
        self._schedule = None
        self._link = None
        self._type = None
        self._statistics = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this SecurityAssessment.
        The OCID of the security assessment.


        :return: The id of this SecurityAssessment.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SecurityAssessment.
        The OCID of the security assessment.


        :param id: The id of this SecurityAssessment.
        :type: str
        """
        self._id = id

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this SecurityAssessment.
        The date and time when the security assessment was created. Conforms to the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this SecurityAssessment.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this SecurityAssessment.
        The date and time when the security assessment was created. Conforms to the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this SecurityAssessment.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this SecurityAssessment.
        The date and time when the security assessment was last updated. Conforms to the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this SecurityAssessment.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this SecurityAssessment.
        The date and time when the security assessment was last updated. Conforms to the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this SecurityAssessment.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this SecurityAssessment.
        The OCID of the compartment that contains the security assessment.


        :return: The compartment_id of this SecurityAssessment.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this SecurityAssessment.
        The OCID of the compartment that contains the security assessment.


        :param compartment_id: The compartment_id of this SecurityAssessment.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this SecurityAssessment.
        The display name of the security assessment.


        :return: The display_name of this SecurityAssessment.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this SecurityAssessment.
        The display name of the security assessment.


        :param display_name: The display_name of this SecurityAssessment.
        :type: str
        """
        self._display_name = display_name

    @property
    def target_ids(self):
        """
        **[Required]** Gets the target_ids of this SecurityAssessment.
        Array of database target OCIDs.


        :return: The target_ids of this SecurityAssessment.
        :rtype: list[str]
        """
        return self._target_ids

    @target_ids.setter
    def target_ids(self, target_ids):
        """
        Sets the target_ids of this SecurityAssessment.
        Array of database target OCIDs.


        :param target_ids: The target_ids of this SecurityAssessment.
        :type: list[str]
        """
        self._target_ids = target_ids

    @property
    def ignored_targets(self):
        """
        Gets the ignored_targets of this SecurityAssessment.
        List containing maps as values.
        Example: `{\"Operations\": [ {\"CostCenter\": \"42\"} ] }`


        :return: The ignored_targets of this SecurityAssessment.
        :rtype: list[object]
        """
        return self._ignored_targets

    @ignored_targets.setter
    def ignored_targets(self, ignored_targets):
        """
        Sets the ignored_targets of this SecurityAssessment.
        List containing maps as values.
        Example: `{\"Operations\": [ {\"CostCenter\": \"42\"} ] }`


        :param ignored_targets: The ignored_targets of this SecurityAssessment.
        :type: list[object]
        """
        self._ignored_targets = ignored_targets

    @property
    def ignored_assessment_ids(self):
        """
        Gets the ignored_assessment_ids of this SecurityAssessment.
        List containing maps as values.
        Example: `{\"Operations\": [ {\"CostCenter\": \"42\"} ] }`


        :return: The ignored_assessment_ids of this SecurityAssessment.
        :rtype: list[object]
        """
        return self._ignored_assessment_ids

    @ignored_assessment_ids.setter
    def ignored_assessment_ids(self, ignored_assessment_ids):
        """
        Sets the ignored_assessment_ids of this SecurityAssessment.
        List containing maps as values.
        Example: `{\"Operations\": [ {\"CostCenter\": \"42\"} ] }`


        :param ignored_assessment_ids: The ignored_assessment_ids of this SecurityAssessment.
        :type: list[object]
        """
        self._ignored_assessment_ids = ignored_assessment_ids

    @property
    def target_version(self):
        """
        Gets the target_version of this SecurityAssessment.
        The version of the target database.


        :return: The target_version of this SecurityAssessment.
        :rtype: str
        """
        return self._target_version

    @target_version.setter
    def target_version(self, target_version):
        """
        Sets the target_version of this SecurityAssessment.
        The version of the target database.


        :param target_version: The target_version of this SecurityAssessment.
        :type: str
        """
        self._target_version = target_version

    @property
    def is_baseline(self):
        """
        Gets the is_baseline of this SecurityAssessment.
        Indicates whether or not the security assessment is set as a baseline. This is applicable only for saved security assessments.


        :return: The is_baseline of this SecurityAssessment.
        :rtype: bool
        """
        return self._is_baseline

    @is_baseline.setter
    def is_baseline(self, is_baseline):
        """
        Sets the is_baseline of this SecurityAssessment.
        Indicates whether or not the security assessment is set as a baseline. This is applicable only for saved security assessments.


        :param is_baseline: The is_baseline of this SecurityAssessment.
        :type: bool
        """
        self._is_baseline = is_baseline

    @property
    def is_deviated_from_baseline(self):
        """
        Gets the is_deviated_from_baseline of this SecurityAssessment.
        Indicates if the assessment has deviated from the baseline.


        :return: The is_deviated_from_baseline of this SecurityAssessment.
        :rtype: bool
        """
        return self._is_deviated_from_baseline

    @is_deviated_from_baseline.setter
    def is_deviated_from_baseline(self, is_deviated_from_baseline):
        """
        Sets the is_deviated_from_baseline of this SecurityAssessment.
        Indicates if the assessment has deviated from the baseline.


        :param is_deviated_from_baseline: The is_deviated_from_baseline of this SecurityAssessment.
        :type: bool
        """
        self._is_deviated_from_baseline = is_deviated_from_baseline

    @property
    def last_compared_baseline_id(self):
        """
        Gets the last_compared_baseline_id of this SecurityAssessment.
        The OCID of the baseline against which the latest security assessment was compared.


        :return: The last_compared_baseline_id of this SecurityAssessment.
        :rtype: str
        """
        return self._last_compared_baseline_id

    @last_compared_baseline_id.setter
    def last_compared_baseline_id(self, last_compared_baseline_id):
        """
        Sets the last_compared_baseline_id of this SecurityAssessment.
        The OCID of the baseline against which the latest security assessment was compared.


        :param last_compared_baseline_id: The last_compared_baseline_id of this SecurityAssessment.
        :type: str
        """
        self._last_compared_baseline_id = last_compared_baseline_id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this SecurityAssessment.
        The current state of the security assessment.

        Allowed values for this property are: "CREATING", "SUCCEEDED", "UPDATING", "DELETING", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this SecurityAssessment.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this SecurityAssessment.
        The current state of the security assessment.


        :param lifecycle_state: The lifecycle_state of this SecurityAssessment.
        :type: str
        """
        allowed_values = ["CREATING", "SUCCEEDED", "UPDATING", "DELETING", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this SecurityAssessment.
        Details about the current state of the security assessment.


        :return: The lifecycle_details of this SecurityAssessment.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this SecurityAssessment.
        Details about the current state of the security assessment.


        :param lifecycle_details: The lifecycle_details of this SecurityAssessment.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def schedule_security_assessment_id(self):
        """
        Gets the schedule_security_assessment_id of this SecurityAssessment.
        The OCID of the security assessment that is responsible for creating this scheduled save assessment.


        :return: The schedule_security_assessment_id of this SecurityAssessment.
        :rtype: str
        """
        return self._schedule_security_assessment_id

    @schedule_security_assessment_id.setter
    def schedule_security_assessment_id(self, schedule_security_assessment_id):
        """
        Sets the schedule_security_assessment_id of this SecurityAssessment.
        The OCID of the security assessment that is responsible for creating this scheduled save assessment.


        :param schedule_security_assessment_id: The schedule_security_assessment_id of this SecurityAssessment.
        :type: str
        """
        self._schedule_security_assessment_id = schedule_security_assessment_id

    @property
    def triggered_by(self):
        """
        Gets the triggered_by of this SecurityAssessment.
        Indicates whether the security assessment was created by system or by a user.

        Allowed values for this property are: "USER", "SYSTEM", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The triggered_by of this SecurityAssessment.
        :rtype: str
        """
        return self._triggered_by

    @triggered_by.setter
    def triggered_by(self, triggered_by):
        """
        Sets the triggered_by of this SecurityAssessment.
        Indicates whether the security assessment was created by system or by a user.


        :param triggered_by: The triggered_by of this SecurityAssessment.
        :type: str
        """
        allowed_values = ["USER", "SYSTEM"]
        if not value_allowed_none_or_none_sentinel(triggered_by, allowed_values):
            triggered_by = 'UNKNOWN_ENUM_VALUE'
        self._triggered_by = triggered_by

    @property
    def description(self):
        """
        Gets the description of this SecurityAssessment.
        The description of the security assessment.


        :return: The description of this SecurityAssessment.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this SecurityAssessment.
        The description of the security assessment.


        :param description: The description of this SecurityAssessment.
        :type: str
        """
        self._description = description

    @property
    def schedule(self):
        """
        Gets the schedule of this SecurityAssessment.
        Schedule to save the assessment periodically in the specified format:
        <version-string>;<version-specific-schedule>

        Allowed version strings - \"v1\"
        v1's version specific schedule -<ss> <mm> <hh> <day-of-week> <day-of-month>
        Each of the above fields potentially introduce constraints. A workrequest is created only
        when clock time satisfies all the constraints. Constraints introduced:
        1. seconds = <ss> (So, the allowed range for <ss> is [0, 59])
        2. minutes = <mm> (So, the allowed range for <mm> is [0, 59])
        3. hours = <hh> (So, the allowed range for <hh> is [0, 23])
        <day-of-week> can be either '*' (without quotes or a number between 1(Monday) and 7(Sunday))
        4. No constraint introduced when it is '*'. When not, day of week must equal the given value
        <day-of-month> can be either '*' (without quotes or a number between 1 and 28)
        5. No constraint introduced when it is '*'. When not, day of month must equal the given value


        :return: The schedule of this SecurityAssessment.
        :rtype: str
        """
        return self._schedule

    @schedule.setter
    def schedule(self, schedule):
        """
        Sets the schedule of this SecurityAssessment.
        Schedule to save the assessment periodically in the specified format:
        <version-string>;<version-specific-schedule>

        Allowed version strings - \"v1\"
        v1's version specific schedule -<ss> <mm> <hh> <day-of-week> <day-of-month>
        Each of the above fields potentially introduce constraints. A workrequest is created only
        when clock time satisfies all the constraints. Constraints introduced:
        1. seconds = <ss> (So, the allowed range for <ss> is [0, 59])
        2. minutes = <mm> (So, the allowed range for <mm> is [0, 59])
        3. hours = <hh> (So, the allowed range for <hh> is [0, 23])
        <day-of-week> can be either '*' (without quotes or a number between 1(Monday) and 7(Sunday))
        4. No constraint introduced when it is '*'. When not, day of week must equal the given value
        <day-of-month> can be either '*' (without quotes or a number between 1 and 28)
        5. No constraint introduced when it is '*'. When not, day of month must equal the given value


        :param schedule: The schedule of this SecurityAssessment.
        :type: str
        """
        self._schedule = schedule

    @property
    def link(self):
        """
        Gets the link of this SecurityAssessment.
        The summary of findings for the security assessment


        :return: The link of this SecurityAssessment.
        :rtype: str
        """
        return self._link

    @link.setter
    def link(self, link):
        """
        Sets the link of this SecurityAssessment.
        The summary of findings for the security assessment


        :param link: The link of this SecurityAssessment.
        :type: str
        """
        self._link = link

    @property
    def type(self):
        """
        **[Required]** Gets the type of this SecurityAssessment.
        The type of this security assessment. The possible types are:

        LATEST: The most up-to-date assessment that is running automatically for a target. It is system generated.
        SAVED: A saved security assessment. LATEST assessments are always saved in order to maintain the history of runs. A SAVED assessment is also generated by a 'refresh' action (triggered by the user).
        SAVE_SCHEDULE: The schedule for periodic saves of LATEST assessments.
        COMPARTMENT: An automatically managed assessment type that stores all details of targets in one compartment.
         This type keeps an up-to-date assessment of all database risks in one compartment. It is automatically updated when
         the latest assessment or refresh action is executed. It is also automatically updated when a target is deleted or move to a different compartment.

        Allowed values for this property are: "LATEST", "SAVED", "SAVE_SCHEDULE", "COMPARTMENT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this SecurityAssessment.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this SecurityAssessment.
        The type of this security assessment. The possible types are:

        LATEST: The most up-to-date assessment that is running automatically for a target. It is system generated.
        SAVED: A saved security assessment. LATEST assessments are always saved in order to maintain the history of runs. A SAVED assessment is also generated by a 'refresh' action (triggered by the user).
        SAVE_SCHEDULE: The schedule for periodic saves of LATEST assessments.
        COMPARTMENT: An automatically managed assessment type that stores all details of targets in one compartment.
         This type keeps an up-to-date assessment of all database risks in one compartment. It is automatically updated when
         the latest assessment or refresh action is executed. It is also automatically updated when a target is deleted or move to a different compartment.


        :param type: The type of this SecurityAssessment.
        :type: str
        """
        allowed_values = ["LATEST", "SAVED", "SAVE_SCHEDULE", "COMPARTMENT"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def statistics(self):
        """
        Gets the statistics of this SecurityAssessment.

        :return: The statistics of this SecurityAssessment.
        :rtype: oci.data_safe.models.SecurityAssessmentStatistics
        """
        return self._statistics

    @statistics.setter
    def statistics(self, statistics):
        """
        Sets the statistics of this SecurityAssessment.

        :param statistics: The statistics of this SecurityAssessment.
        :type: oci.data_safe.models.SecurityAssessmentStatistics
        """
        self._statistics = statistics

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this SecurityAssessment.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this SecurityAssessment.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this SecurityAssessment.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this SecurityAssessment.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this SecurityAssessment.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this SecurityAssessment.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this SecurityAssessment.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this SecurityAssessment.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this SecurityAssessment.
        System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this SecurityAssessment.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this SecurityAssessment.
        System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this SecurityAssessment.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

ENCRYPTED_CONTENT_FORMAT_FULL_MESSAGE = 0


class EncryptedDataHeader(object):
    def __init__(
        self,
        encrypted_data_keys,
        iv_bytes,
        algorithm_id,
        additional_authenticated_data_bytes
    ):
        self.encrypted_content_format = ENCRYPTED_CONTENT_FORMAT_FULL_MESSAGE
        self.encrypted_data_keys = encrypted_data_keys
        self.iv_bytes = iv_bytes
        self.algorithm_id = algorithm_id
        self.additional_authenticated_data_bytes = additional_authenticated_data_bytes


class EncryptedDataHeaderDataEncryptionKey(object):
    def __init__(self, master_key_id, vault_id, encrypted_data_key_bytes, region):
        self.master_key_id = master_key_id
        self.vault_id = vault_id
        self.encrypted_data_key_bytes = encrypted_data_key_bytes
        self.region = region



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Reference(object):
    """
    Reference contains application configuration information.
    """

    #: A constant which can be used with the type property of a Reference.
    #: This constant has a value of "ORACLE_DATA_ASSET"
    TYPE_ORACLE_DATA_ASSET = "ORACLE_DATA_ASSET"

    #: A constant which can be used with the type property of a Reference.
    #: This constant has a value of "ORACLE_OBJECT_STORAGE_DATA_ASSET"
    TYPE_ORACLE_OBJECT_STORAGE_DATA_ASSET = "ORACLE_OBJECT_STORAGE_DATA_ASSET"

    #: A constant which can be used with the type property of a Reference.
    #: This constant has a value of "ORACLE_ATP_DATA_ASSET"
    TYPE_ORACLE_ATP_DATA_ASSET = "ORACLE_ATP_DATA_ASSET"

    #: A constant which can be used with the type property of a Reference.
    #: This constant has a value of "ORACLE_ADWC_DATA_ASSET"
    TYPE_ORACLE_ADWC_DATA_ASSET = "ORACLE_ADWC_DATA_ASSET"

    #: A constant which can be used with the type property of a Reference.
    #: This constant has a value of "MYSQL_DATA_ASSET"
    TYPE_MYSQL_DATA_ASSET = "MYSQL_DATA_ASSET"

    #: A constant which can be used with the type property of a Reference.
    #: This constant has a value of "GENERIC_JDBC_DATA_ASSET"
    TYPE_GENERIC_JDBC_DATA_ASSET = "GENERIC_JDBC_DATA_ASSET"

    def __init__(self, **kwargs):
        """
        Initializes a new Reference object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this Reference.
        :type key: str

        :param name:
            The value to assign to the name property of this Reference.
        :type name: str

        :param identifier:
            The value to assign to the identifier property of this Reference.
        :type identifier: str

        :param identifier_path:
            The value to assign to the identifier_path property of this Reference.
        :type identifier_path: str

        :param description:
            The value to assign to the description property of this Reference.
        :type description: str

        :param type:
            The value to assign to the type property of this Reference.
            Allowed values for this property are: "ORACLE_DATA_ASSET", "ORACLE_OBJECT_STORAGE_DATA_ASSET", "ORACLE_ATP_DATA_ASSET", "ORACLE_ADWC_DATA_ASSET", "MYSQL_DATA_ASSET", "GENERIC_JDBC_DATA_ASSET", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param target_object:
            The value to assign to the target_object property of this Reference.
        :type target_object: object

        :param application_key:
            The value to assign to the application_key property of this Reference.
        :type application_key: str

        :param used_by:
            The value to assign to the used_by property of this Reference.
        :type used_by: list[oci.data_integration.models.ReferenceUsedBy]

        :param child_references:
            The value to assign to the child_references property of this Reference.
        :type child_references: list[oci.data_integration.models.ChildReference]

        """
        self.swagger_types = {
            'key': 'str',
            'name': 'str',
            'identifier': 'str',
            'identifier_path': 'str',
            'description': 'str',
            'type': 'str',
            'target_object': 'object',
            'application_key': 'str',
            'used_by': 'list[ReferenceUsedBy]',
            'child_references': 'list[ChildReference]'
        }

        self.attribute_map = {
            'key': 'key',
            'name': 'name',
            'identifier': 'identifier',
            'identifier_path': 'identifierPath',
            'description': 'description',
            'type': 'type',
            'target_object': 'targetObject',
            'application_key': 'applicationKey',
            'used_by': 'usedBy',
            'child_references': 'childReferences'
        }

        self._key = None
        self._name = None
        self._identifier = None
        self._identifier_path = None
        self._description = None
        self._type = None
        self._target_object = None
        self._application_key = None
        self._used_by = None
        self._child_references = None

    @property
    def key(self):
        """
        Gets the key of this Reference.
        The reference's key, key of the object that is being used by a published object or its dependents.


        :return: The key of this Reference.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this Reference.
        The reference's key, key of the object that is being used by a published object or its dependents.


        :param key: The key of this Reference.
        :type: str
        """
        self._key = key

    @property
    def name(self):
        """
        Gets the name of this Reference.
        The name of reference object.


        :return: The name of this Reference.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Reference.
        The name of reference object.


        :param name: The name of this Reference.
        :type: str
        """
        self._name = name

    @property
    def identifier(self):
        """
        Gets the identifier of this Reference.
        The identifier of reference object.


        :return: The identifier of this Reference.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this Reference.
        The identifier of reference object.


        :param identifier: The identifier of this Reference.
        :type: str
        """
        self._identifier = identifier

    @property
    def identifier_path(self):
        """
        Gets the identifier_path of this Reference.
        The identifier path of reference object.


        :return: The identifier_path of this Reference.
        :rtype: str
        """
        return self._identifier_path

    @identifier_path.setter
    def identifier_path(self, identifier_path):
        """
        Sets the identifier_path of this Reference.
        The identifier path of reference object.


        :param identifier_path: The identifier_path of this Reference.
        :type: str
        """
        self._identifier_path = identifier_path

    @property
    def description(self):
        """
        Gets the description of this Reference.
        The description of reference object.


        :return: The description of this Reference.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Reference.
        The description of reference object.


        :param description: The description of this Reference.
        :type: str
        """
        self._description = description

    @property
    def type(self):
        """
        Gets the type of this Reference.
        The type of reference object.

        Allowed values for this property are: "ORACLE_DATA_ASSET", "ORACLE_OBJECT_STORAGE_DATA_ASSET", "ORACLE_ATP_DATA_ASSET", "ORACLE_ADWC_DATA_ASSET", "MYSQL_DATA_ASSET", "GENERIC_JDBC_DATA_ASSET", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this Reference.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Reference.
        The type of reference object.


        :param type: The type of this Reference.
        :type: str
        """
        allowed_values = ["ORACLE_DATA_ASSET", "ORACLE_OBJECT_STORAGE_DATA_ASSET", "ORACLE_ATP_DATA_ASSET", "ORACLE_ADWC_DATA_ASSET", "MYSQL_DATA_ASSET", "GENERIC_JDBC_DATA_ASSET"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def target_object(self):
        """
        Gets the target_object of this Reference.
        The new reference object to use instead of the original reference. For example, this can be a data asset reference.


        :return: The target_object of this Reference.
        :rtype: object
        """
        return self._target_object

    @target_object.setter
    def target_object(self, target_object):
        """
        Sets the target_object of this Reference.
        The new reference object to use instead of the original reference. For example, this can be a data asset reference.


        :param target_object: The target_object of this Reference.
        :type: object
        """
        self._target_object = target_object

    @property
    def application_key(self):
        """
        Gets the application_key of this Reference.
        The application key of the reference object.


        :return: The application_key of this Reference.
        :rtype: str
        """
        return self._application_key

    @application_key.setter
    def application_key(self, application_key):
        """
        Sets the application_key of this Reference.
        The application key of the reference object.


        :param application_key: The application_key of this Reference.
        :type: str
        """
        self._application_key = application_key

    @property
    def used_by(self):
        """
        Gets the used_by of this Reference.
        List of published objects where this is used.


        :return: The used_by of this Reference.
        :rtype: list[oci.data_integration.models.ReferenceUsedBy]
        """
        return self._used_by

    @used_by.setter
    def used_by(self, used_by):
        """
        Sets the used_by of this Reference.
        List of published objects where this is used.


        :param used_by: The used_by of this Reference.
        :type: list[oci.data_integration.models.ReferenceUsedBy]
        """
        self._used_by = used_by

    @property
    def child_references(self):
        """
        Gets the child_references of this Reference.
        List of references that are dependent on this reference.


        :return: The child_references of this Reference.
        :rtype: list[oci.data_integration.models.ChildReference]
        """
        return self._child_references

    @child_references.setter
    def child_references(self, child_references):
        """
        Sets the child_references of this Reference.
        List of references that are dependent on this reference.


        :param child_references: The child_references of this Reference.
        :type: list[oci.data_integration.models.ChildReference]
        """
        self._child_references = child_references

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class QueryWorkRequest(object):
    """
    Job details outlining parameters specified when job was submitted.
    """

    #: A constant which can be used with the status property of a QueryWorkRequest.
    #: This constant has a value of "ACCEPTED"
    STATUS_ACCEPTED = "ACCEPTED"

    #: A constant which can be used with the status property of a QueryWorkRequest.
    #: This constant has a value of "CANCELED"
    STATUS_CANCELED = "CANCELED"

    #: A constant which can be used with the status property of a QueryWorkRequest.
    #: This constant has a value of "FAILED"
    STATUS_FAILED = "FAILED"

    #: A constant which can be used with the status property of a QueryWorkRequest.
    #: This constant has a value of "IN_PROGRESS"
    STATUS_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the status property of a QueryWorkRequest.
    #: This constant has a value of "SUCCEEDED"
    STATUS_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the operation_type property of a QueryWorkRequest.
    #: This constant has a value of "EXECUTE_QUERY_JOB"
    OPERATION_TYPE_EXECUTE_QUERY_JOB = "EXECUTE_QUERY_JOB"

    #: A constant which can be used with the operation_type property of a QueryWorkRequest.
    #: This constant has a value of "EXECUTE_PURGE_JOB"
    OPERATION_TYPE_EXECUTE_PURGE_JOB = "EXECUTE_PURGE_JOB"

    #: A constant which can be used with the mode property of a QueryWorkRequest.
    #: This constant has a value of "FOREGROUND"
    MODE_FOREGROUND = "FOREGROUND"

    #: A constant which can be used with the mode property of a QueryWorkRequest.
    #: This constant has a value of "BACKGROUND"
    MODE_BACKGROUND = "BACKGROUND"

    #: A constant which can be used with the sub_system property of a QueryWorkRequest.
    #: This constant has a value of "LOG"
    SUB_SYSTEM_LOG = "LOG"

    def __init__(self, **kwargs):
        """
        Initializes a new QueryWorkRequest object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this QueryWorkRequest.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this QueryWorkRequest.
        :type compartment_id: str

        :param time_started:
            The value to assign to the time_started property of this QueryWorkRequest.
        :type time_started: datetime

        :param time_accepted:
            The value to assign to the time_accepted property of this QueryWorkRequest.
        :type time_accepted: datetime

        :param time_finished:
            The value to assign to the time_finished property of this QueryWorkRequest.
        :type time_finished: datetime

        :param time_expires:
            The value to assign to the time_expires property of this QueryWorkRequest.
        :type time_expires: datetime

        :param percent_complete:
            The value to assign to the percent_complete property of this QueryWorkRequest.
        :type percent_complete: int

        :param status:
            The value to assign to the status property of this QueryWorkRequest.
            Allowed values for this property are: "ACCEPTED", "CANCELED", "FAILED", "IN_PROGRESS", "SUCCEEDED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param operation_type:
            The value to assign to the operation_type property of this QueryWorkRequest.
            Allowed values for this property are: "EXECUTE_QUERY_JOB", "EXECUTE_PURGE_JOB", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type operation_type: str

        :param mode:
            The value to assign to the mode property of this QueryWorkRequest.
            Allowed values for this property are: "FOREGROUND", "BACKGROUND", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type mode: str

        :param time_background_at:
            The value to assign to the time_background_at property of this QueryWorkRequest.
        :type time_background_at: datetime

        :param time_filter:
            The value to assign to the time_filter property of this QueryWorkRequest.
        :type time_filter: oci.log_analytics.models.TimeRange

        :param scope_filters:
            The value to assign to the scope_filters property of this QueryWorkRequest.
        :type scope_filters: list[oci.log_analytics.models.ScopeFilter]

        :param sub_system:
            The value to assign to the sub_system property of this QueryWorkRequest.
            Allowed values for this property are: "LOG", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type sub_system: str

        :param display_query_string:
            The value to assign to the display_query_string property of this QueryWorkRequest.
        :type display_query_string: str

        :param internal_query_string:
            The value to assign to the internal_query_string property of this QueryWorkRequest.
        :type internal_query_string: str

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'time_started': 'datetime',
            'time_accepted': 'datetime',
            'time_finished': 'datetime',
            'time_expires': 'datetime',
            'percent_complete': 'int',
            'status': 'str',
            'operation_type': 'str',
            'mode': 'str',
            'time_background_at': 'datetime',
            'time_filter': 'TimeRange',
            'scope_filters': 'list[ScopeFilter]',
            'sub_system': 'str',
            'display_query_string': 'str',
            'internal_query_string': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'time_started': 'timeStarted',
            'time_accepted': 'timeAccepted',
            'time_finished': 'timeFinished',
            'time_expires': 'timeExpires',
            'percent_complete': 'percentComplete',
            'status': 'status',
            'operation_type': 'operationType',
            'mode': 'mode',
            'time_background_at': 'timeBackgroundAt',
            'time_filter': 'timeFilter',
            'scope_filters': 'scopeFilters',
            'sub_system': 'subSystem',
            'display_query_string': 'displayQueryString',
            'internal_query_string': 'internalQueryString'
        }

        self._id = None
        self._compartment_id = None
        self._time_started = None
        self._time_accepted = None
        self._time_finished = None
        self._time_expires = None
        self._percent_complete = None
        self._status = None
        self._operation_type = None
        self._mode = None
        self._time_background_at = None
        self._time_filter = None
        self._scope_filters = None
        self._sub_system = None
        self._display_query_string = None
        self._internal_query_string = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this QueryWorkRequest.
        Unique OCID identifier to reference this query job work Request with.


        :return: The id of this QueryWorkRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueryWorkRequest.
        Unique OCID identifier to reference this query job work Request with.


        :param id: The id of this QueryWorkRequest.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this QueryWorkRequest.
        Compartment Identifier `OCID]`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this QueryWorkRequest.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this QueryWorkRequest.
        Compartment Identifier `OCID]`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this QueryWorkRequest.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def time_started(self):
        """
        **[Required]** Gets the time_started of this QueryWorkRequest.
        When the job was started.


        :return: The time_started of this QueryWorkRequest.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this QueryWorkRequest.
        When the job was started.


        :param time_started: The time_started of this QueryWorkRequest.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_accepted(self):
        """
        Gets the time_accepted of this QueryWorkRequest.
        When the work request was accepted. Should match timeStarted in all cases.


        :return: The time_accepted of this QueryWorkRequest.
        :rtype: datetime
        """
        return self._time_accepted

    @time_accepted.setter
    def time_accepted(self, time_accepted):
        """
        Sets the time_accepted of this QueryWorkRequest.
        When the work request was accepted. Should match timeStarted in all cases.


        :param time_accepted: The time_accepted of this QueryWorkRequest.
        :type: datetime
        """
        self._time_accepted = time_accepted

    @property
    def time_finished(self):
        """
        Gets the time_finished of this QueryWorkRequest.
        When the job finished execution.


        :return: The time_finished of this QueryWorkRequest.
        :rtype: datetime
        """
        return self._time_finished

    @time_finished.setter
    def time_finished(self, time_finished):
        """
        Sets the time_finished of this QueryWorkRequest.
        When the job finished execution.


        :param time_finished: The time_finished of this QueryWorkRequest.
        :type: datetime
        """
        self._time_finished = time_finished

    @property
    def time_expires(self):
        """
        Gets the time_expires of this QueryWorkRequest.
        When the job will expire.


        :return: The time_expires of this QueryWorkRequest.
        :rtype: datetime
        """
        return self._time_expires

    @time_expires.setter
    def time_expires(self, time_expires):
        """
        Sets the time_expires of this QueryWorkRequest.
        When the job will expire.


        :param time_expires: The time_expires of this QueryWorkRequest.
        :type: datetime
        """
        self._time_expires = time_expires

    @property
    def percent_complete(self):
        """
        Gets the percent_complete of this QueryWorkRequest.
        Percentage progress completion of the query.


        :return: The percent_complete of this QueryWorkRequest.
        :rtype: int
        """
        return self._percent_complete

    @percent_complete.setter
    def percent_complete(self, percent_complete):
        """
        Sets the percent_complete of this QueryWorkRequest.
        Percentage progress completion of the query.


        :param percent_complete: The percent_complete of this QueryWorkRequest.
        :type: int
        """
        self._percent_complete = percent_complete

    @property
    def status(self):
        """
        Gets the status of this QueryWorkRequest.
        Work request status.

        Allowed values for this property are: "ACCEPTED", "CANCELED", "FAILED", "IN_PROGRESS", "SUCCEEDED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this QueryWorkRequest.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this QueryWorkRequest.
        Work request status.


        :param status: The status of this QueryWorkRequest.
        :type: str
        """
        allowed_values = ["ACCEPTED", "CANCELED", "FAILED", "IN_PROGRESS", "SUCCEEDED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def operation_type(self):
        """
        Gets the operation_type of this QueryWorkRequest.
        Asynchronous action name.

        Allowed values for this property are: "EXECUTE_QUERY_JOB", "EXECUTE_PURGE_JOB", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The operation_type of this QueryWorkRequest.
        :rtype: str
        """
        return self._operation_type

    @operation_type.setter
    def operation_type(self, operation_type):
        """
        Sets the operation_type of this QueryWorkRequest.
        Asynchronous action name.


        :param operation_type: The operation_type of this QueryWorkRequest.
        :type: str
        """
        allowed_values = ["EXECUTE_QUERY_JOB", "EXECUTE_PURGE_JOB"]
        if not value_allowed_none_or_none_sentinel(operation_type, allowed_values):
            operation_type = 'UNKNOWN_ENUM_VALUE'
        self._operation_type = operation_type

    @property
    def mode(self):
        """
        **[Required]** Gets the mode of this QueryWorkRequest.
        Current execution mode for the job.

        Allowed values for this property are: "FOREGROUND", "BACKGROUND", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The mode of this QueryWorkRequest.
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """
        Sets the mode of this QueryWorkRequest.
        Current execution mode for the job.


        :param mode: The mode of this QueryWorkRequest.
        :type: str
        """
        allowed_values = ["FOREGROUND", "BACKGROUND"]
        if not value_allowed_none_or_none_sentinel(mode, allowed_values):
            mode = 'UNKNOWN_ENUM_VALUE'
        self._mode = mode

    @property
    def time_background_at(self):
        """
        Gets the time_background_at of this QueryWorkRequest.
        When the job was put in to the background.


        :return: The time_background_at of this QueryWorkRequest.
        :rtype: datetime
        """
        return self._time_background_at

    @time_background_at.setter
    def time_background_at(self, time_background_at):
        """
        Sets the time_background_at of this QueryWorkRequest.
        When the job was put in to the background.


        :param time_background_at: The time_background_at of this QueryWorkRequest.
        :type: datetime
        """
        self._time_background_at = time_background_at

    @property
    def time_filter(self):
        """
        Gets the time_filter of this QueryWorkRequest.

        :return: The time_filter of this QueryWorkRequest.
        :rtype: oci.log_analytics.models.TimeRange
        """
        return self._time_filter

    @time_filter.setter
    def time_filter(self, time_filter):
        """
        Sets the time_filter of this QueryWorkRequest.

        :param time_filter: The time_filter of this QueryWorkRequest.
        :type: oci.log_analytics.models.TimeRange
        """
        self._time_filter = time_filter

    @property
    def scope_filters(self):
        """
        Gets the scope_filters of this QueryWorkRequest.
        List of filters applied when the query executed.


        :return: The scope_filters of this QueryWorkRequest.
        :rtype: list[oci.log_analytics.models.ScopeFilter]
        """
        return self._scope_filters

    @scope_filters.setter
    def scope_filters(self, scope_filters):
        """
        Sets the scope_filters of this QueryWorkRequest.
        List of filters applied when the query executed.


        :param scope_filters: The scope_filters of this QueryWorkRequest.
        :type: list[oci.log_analytics.models.ScopeFilter]
        """
        self._scope_filters = scope_filters

    @property
    def sub_system(self):
        """
        **[Required]** Gets the sub_system of this QueryWorkRequest.
        Default subsystem to qualify fields with in the queryString if not specified.

        Allowed values for this property are: "LOG", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The sub_system of this QueryWorkRequest.
        :rtype: str
        """
        return self._sub_system

    @sub_system.setter
    def sub_system(self, sub_system):
        """
        Sets the sub_system of this QueryWorkRequest.
        Default subsystem to qualify fields with in the queryString if not specified.


        :param sub_system: The sub_system of this QueryWorkRequest.
        :type: str
        """
        allowed_values = ["LOG"]
        if not value_allowed_none_or_none_sentinel(sub_system, allowed_values):
            sub_system = 'UNKNOWN_ENUM_VALUE'
        self._sub_system = sub_system

    @property
    def display_query_string(self):
        """
        **[Required]** Gets the display_query_string of this QueryWorkRequest.
        Display version of the user speciified queryString.


        :return: The display_query_string of this QueryWorkRequest.
        :rtype: str
        """
        return self._display_query_string

    @display_query_string.setter
    def display_query_string(self, display_query_string):
        """
        Sets the display_query_string of this QueryWorkRequest.
        Display version of the user speciified queryString.


        :param display_query_string: The display_query_string of this QueryWorkRequest.
        :type: str
        """
        self._display_query_string = display_query_string

    @property
    def internal_query_string(self):
        """
        **[Required]** Gets the internal_query_string of this QueryWorkRequest.
        Internal version of the user specified queryString.


        :return: The internal_query_string of this QueryWorkRequest.
        :rtype: str
        """
        return self._internal_query_string

    @internal_query_string.setter
    def internal_query_string(self, internal_query_string):
        """
        Sets the internal_query_string of this QueryWorkRequest.
        Internal version of the user specified queryString.


        :param internal_query_string: The internal_query_string of this QueryWorkRequest.
        :type: str
        """
        self._internal_query_string = internal_query_string

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
